.. role:: header_no_toc
  :class: class_header_no_toc

.. title:: Welcome to tree's documentation!

:tocdepth: 2

.. rubric:: :header_no_toc:`Welcome to tree's documentation!`

This is the Sphinx documentation for the Python product tree

Introduction
------------

* :ref:`What's new in tree? <changelog>`
* :ref:`Installation <install>`
* :ref:`Introduction to the Tree <intro>`
* :ref:`Tree environment configuration <config>`

Reference
---------

.. toctree::
   :maxdepth: 1

   api



Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
